Anonymizes email addresses by replacing them with sequential fake emails.
Examples
emails <- c("john@company.com", "not_an_email", "jane at work dot org")
anon_email(emails)
#> [1] "user001@domain.com" "not_an_email" "user002@domain.com"
Anonymizes email addresses by replacing them with sequential fake emails.
emails <- c("john@company.com", "not_an_email", "jane at work dot org")
anon_email(emails)
#> [1] "user001@domain.com" "not_an_email" "user002@domain.com"