Build an anonymized inventory of objects in an environment or list
Source:R/runtime_helpers.R
anon_inventory.RdBuild an anonymized inventory of objects in an environment or list
Arguments
- envir
An environment or named/unnamed list of objects.
- selection
Optional character vector of object names to include.
- pattern_list
A list of patterns to search for and replace. Can include:
Named elements where names are replacement values and values are one or more patterns to match
Unnamed elements where one or more patterns are replaced with
default_replacementThis parameter is combined with the global optiongetOption("anon.pattern_list").
- default_replacement
Value to use as the default replacement value when no specific replacement is provided. Default is
getOption("anon.default_replacement", default = "\[REDACTED\]").- check_approximate
Logical indicating whether to check for approximate matches using string distance. Default is
getOption("anon.check_approximate", default = FALSE).- max_distance
Maximum string distance for approximate matching when
check_approximateisTRUE. Default is2.