Normalize supported anon objects into a structured payload suitable for
downstream AI/tooling use or for conversion with as_anon_json().
Unsupported custom classes error with the object path to make failures easy
to diagnose.
Normalize supported anon objects into a structured payload suitable for
downstream AI/tooling use or for conversion with as_anon_json().
Unsupported custom classes error with the object path to make failures easy
to diagnose.