Displays combined anonymized objects in a format suitable for LLM prompts. Each object is clearly delineated and presented with appropriate context.
Usage
# S3 method for class 'anon_context_collection'
print(x, ...)Displays combined anonymized objects in a format suitable for LLM prompts. Each object is clearly delineated and presented with appropriate context.
# S3 method for class 'anon_context_collection'
print(x, ...)